@@ -175,7 +175,7 @@ impl<P: Config, ConstraintF: Field, PG: ConfigGadget<P, ConstraintF>> PathVar<P,
         leaf_params: &LeafParam<PG, P, ConstraintF>,
         two_to_one_params: &TwoToOneParam<PG, P, ConstraintF>,
         leaf: &PG::Leaf,
-    ) -> Result<PG::InnerDigest, SynthesisError> {
+    ) -> MMRResult<PG::InnerDigest> {
         let claimed_leaf_hash = PG::LeafHash::evaluate(leaf_params, leaf).unwrap();
         let converted_leaf_hash = PG::LeafInnerConverter::convert(claimed_leaf_hash).unwrap();
 
@@ -189,17 +189,17 @@ impl<P: Config, ConstraintF: Field, PG: ConfigGadget<P, ConstraintF>> PathVar<P,
         converted_leaf_hash: &PG::InnerDigest,
     ) -> MMRResult<Vec<PG::InnerDigest>> {
         // special handle the only 1 leaf MMR
-        if self.mmr_size.value() == 1 && self.auth_path.len() == 1 {
-            return Ok(vec![converted_leaf_hash]);
+        if self.mmr_size.value().unwrap() == 1 && self.auth_path.len() == 1 {
+            return Ok(vec![converted_leaf_hash.clone()]);
         }
 
         let path_iter = self.auth_path.iter();
-        let peaks = get_peaks(self.mmr_size.value());    
-        let leaves = vec![(self.leaf_index, converted_leaf_hash)];
+        let peaks = get_peaks(self.mmr_size.value().unwrap());    
+        let leaves = vec![(self.leaf_index.value().unwrap(), converted_leaf_hash)];
         let mut peaks_hashes: Vec<PG::InnerDigest> = Vec::with_capacity(peaks.len() + 1);
         for peak_pos in peaks {
-            let mut leaves: Vec<_> = take_while_vec(&mut leaves,|(pos, _)| *pos <= peak_pos);
-            let peak_root = if leaves.len() == 1 && leaves[0].0 == peak_pos {
+            let mut leaves: Vec<_> = take_while_vec(&mut leaves,|(pos, _)| *pos.value().unwrap() <= peak_pos);
+            let peak_root = if leaves.len() == 1 && leaves[0].0.value().unwrap() == peak_pos {
                 // leaf is the peak
                 leaves.remove(0).1
             } else if leaves.is_empty() {
@@ -212,8 +212,10 @@ impl<P: Config, ConstraintF: Field, PG: ConfigGadget<P, ConstraintF>> PathVar<P,
                     break;
                 }
             } else {
-                Self::calculate_peak_root(two_to_one_params,leaves, peak_pos, &mut path_iter).unwrap()
-            };
+                let peak_resut = Self::calculate_peak_root(two_to_one_params, leaves, peak_pos, &mut path_iter).unwrap();
+                &peak_result
+            }
+
             peaks_hashes.push(peak_root.clone());
         }
     
